.. module:: tests.guest

*****
guest
*****

This module provides functions used to by :py:mod:`pytest` to run tests against
the following objects:

- :py:class:`wwdtm.guest.Guest`
- :py:class:`wwdtm.guest.GuestAppearances`
- :py:class:`wwdtm.guest.GuestUtility`

test_guest_appearances
======================

.. automodule:: tests.guest.test_guest_appearances
    :members:
    :undoc-members:

test_guest_guest
================

.. automodule:: tests.guest.test_guest_guest
    :members:
    :undoc-members:

test_guest_utility
==================

.. automodule:: tests.guest.test_guest_utility
    :members:
    :undoc-members:
